Crate kcr_kamaji_clastix_io

Crate kcr_kamaji_clastix_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the kamaji.clastix.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

kamaji.clastix.io/v1alpha1

  • DataStore
  • TenantControlPlane

Modules

v1alpha1